package gr.uoc.csd.hy539.helloworld;

import android.os.Bundle;
import android.app.Activity;
import android.content.Intent;
import android.view.Menu;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

/* 
 * Activities are the mechanism for the interaction with the user.
 * 
 * Each Activity represents a single screen and provides the UI,
 * handles user events and performs actions.
 * 
 * You can read more at:
 * http://developer.android.com/guide/components/activities.html.
 *
 * This is the first Activity the user will see, when it launches the
 * application.
 * 
 * While creating the current Android project, we also created this first
 * Activity. Now, we will enrich it with some functionality. You can follow the
 * successive implementation steps by reading the comments.
 * 
 */
public class MainActivity extends Activity {
	TextView textView;
	EditText editText1;
	Button button1, button2;
	
	/*
	 * Step 1
	 *
	 * When an Activity is about to be created, it is notified by calling its
	 * onCreate(...) method. We should override this method to do the following
	 * steps:
	 * 		1) call super.onCreate(...)
	 * 		2) set its UI ( e.g., by calling setContentView() )
	 * 		3) initialize the fields
	 * 
	 * Note that the UI is a hierarchy of View and ViewGroup objects, which can
	 * be presented as a tree. We store the UI's as .xml files in the directory
	 * "res/layout/". We define "android:id" attributes to the elements that we
	 * want to refer from our Java code (e.g., here) and we refer to them using
	 * the corresponding R.id field.
	 * 
	 * You can read more about Android UI's at:
	 * http://developer.android.com/guide/topics/ui/overview.html
	 */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		textView = (TextView) findViewById(R.id.textView1);
		editText1 = (EditText) findViewById(R.id.editText1);
		button1 = (Button) findViewById(R.id.button1);
		button2 = (Button) findViewById(R.id.button2);
		
		/*
		 * Step 1
		 * 
		 * textView object is a reference to the corresponding TextView element
		 * defined in res/layout/activity_main.xml
		 * We call its setText(...) method to dynamically set its text. 
		 */
		textView.setText("HY-539, Android tutorial");

		/*
		 * Step 2 - onClick listener for button1
		 * 
		 * Before using the code below, make sure to implement the
		 * SecondActivity class.
		 *
		 * When we click this button, we want to start the SecondActivity and
		 * send to it some data. So we will get the text from editText1 and
		 * put it in the Intent object.
		 * 
		 * Note that Activities, Services, and Broadcast Receivers are activated
		 * through intents, which are:
		 * 		- A high-level facility to perform IPC
		 * 		- Passive data structure describing an operation to be performed
		 * 		- Description of something that has happened and is being announced
		 */
		button1.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				Intent intent = new Intent();
				intent.setClass(MainActivity.this, SecondActivity.class);
				intent.putExtra("string1", editText1.getText().toString());
				startActivity(intent);
			}
		});
		
		/*
		 * Step 4 - onClick listener for button2
		 * 
		 * Before using the code below, make sure to implement the
		 * WifiScanActivity class.
		 * 
		 * When we click this button, we want to start the WifiScanActivity, which
		 * performs 802.11 RSSI measurements and displays them on screen. 
		 */
		button2.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				Intent intent = new Intent();
				intent.setClass(MainActivity.this, WifiScanActivity.class);
				startActivity(intent);
			}
		});

	}
	
	/*
	 * Below are overrided/implemented all Activity lifecycle callback methods, for
	 * educational needs. Usually, we need only to implement onCreate(...) and
	 * onDestroy(...) 
	 */

	@Override
	protected void onStart() {
		super.onStart();
		// The activity is about to become visible.
	}

	@Override
	protected void onResume() {
		super.onResume();
		// The activity has become visible (it is now "resumed").
	}

	@Override
	protected void onPause() {
		super.onPause();
		// Another activity is taking focus (this activity is about to be
		// "paused").
	}

	@Override
	protected void onStop() {
		super.onStop();
		// The activity is no longer visible (it is now "stopped")
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		/*
		 * The activity is about to be destroyed.
		 * Here we should release all remaining resources.
		 * 
		 * For example, if our activity has a thread running in the background
		 * to download data from the network, it might create that thread in
		 * onCreate() and then stop the thread in onDestroy().
		 */
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.activity_main, menu);
		return true;
		// This method is called when the special button "menu" is pressed.
	}
}
